@@ -1,4 +1,5 @@
 # -*- encoding: utf-8 -*-
+
 # Django settings for merengue project.
 
 from os import path
@@ -11,6 +12,7 @@ BASEDIR = path.dirname(path.abspath(__file__))
 DEBUG = True
 TEMPLATE_DEBUG = DEBUG
 DEBUG_TOOLBAR = DEBUG
+HTTP_ERRORS_DEBUG = DEBUG
 
 ADMINS = (
     ('Your Name', 'youremail@yourdomain.org'),
@@ -25,6 +27,11 @@ DATABASE_PASSWORD = ''         # Not used with sqlite3.
 DATABASE_HOST = ''             # Set to empty string for localhost. Not used with sqlite3.
 DATABASE_PORT = ''             # Set to empty string for default. Not used with sqlite3.
 
+if DATABASE_ENGINE == 'postgresql_psycopg2':
+    DATABASE_OPTIONS = {
+        'autocommit': True,
+    }
+
 # Local time zone for this installation. Choices can be found here:
 # http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
 # although not all choices may be available on all operating systems.
@@ -34,11 +41,11 @@ TIME_ZONE = 'Europe/Madrid'
 
 # Language code for this installation. All choices can be found here:
 # http://www.i18nguy.com/unicode/language-identifiers.html
-LANGUAGE_CODE = 'es'
+LANGUAGE_CODE = 'en'
 
 LANGUAGES = (
-    ('es', ugettext('Español')),
     ('en', ugettext('English')),
+    ('es', ugettext('Español')),
     ('fr', ugettext('Français')),
 )
 
@@ -54,6 +61,8 @@ USE_GIS = False
 
 if USE_GIS:
     INSTALLED_APPS += ('django.contrib.gis', 'merengue.places', )
+    if DATABASE_ENGINE == 'postgresql_psycopg2':
+        TEST_DB_CREATION_SUFFIX = 'WITH TEMPLATE template_postgis'
 
 # Absolute path to the directory that holds media.
 # Example: "/home/media/media.lawrence.com/"
@@ -61,7 +70,7 @@ MEDIA_ROOT = path.join(BASEDIR, 'media/')
 
 # URL that handles the media served from MEDIA_ROOT. Make sure to use a
 # trailing slash if there is a path component (optional in other cases).
-# Examples: "http://media.lawrence.com", "http://example.com/media/"
+# Examples: "http://media.lawrence.com", "http://example.com/meencodingdia/"
 MEDIA_URL = '/media/'
 
 # URL prefix for admin media -- CSS, JavaScript and images. Make sure to use a
@@ -87,6 +96,7 @@ LOGIN_URL = '/account/login/'
 
 INSTALLED_APPS += (
     # put here your project django apps
+    'website',
 )
 
 SVNDIR = path.join(BASEDIR, 'apps')
@@ -116,8 +126,6 @@ TINYMCE_EXTRA_MEDIA = {
    'css': [],
 }
 
-SEARCHBAR_MIN_RESULTS = 5
-
 LOGOUT_PROTECTED_URL_REDIRECTS = (
     #(r'^/regularexpresion/(.*)$', '/redirect_url'),
 )
