@@ -1,9 +1,26 @@
+# Copyright (c) 2010 by Yaco Sistemas
+#
+# This file is part of Merengue.
+#
+# Merengue is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Merengue is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with Merengue.  If not, see <http://www.gnu.org/licenses/>.
+
 # -*- coding: utf-8 -*-
 from models import Chunk
 
 from cmsutils.forms.widgets import TinyMCE
 
-from merengue.base.admin import BaseAdmin
+from merengue.base.admin import PluginAdmin
 from plugins.chunks.forms.forms import ChunkAdminModelForm
 
 
@@ -22,7 +39,7 @@ class TransTinyMCEWidget(TinyMCE):
         return TinyMCE.render(self, field_name, value, attrs)
 
 
-class ChunkAdmin(BaseAdmin):
+class ChunkAdmin(PluginAdmin):
     list_display = ('key', )
     search_fields = ('key', 'content')
     form = ChunkAdminModelForm
