@@ -1,3 +1,20 @@
+# Copyright (c) 2010 by Yaco Sistemas
+#
+# This file is part of Merengue.
+#
+# Merengue is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Merengue is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with Merengue.  If not, see <http://www.gnu.org/licenses/>.
+
 from django.utils.translation import ugettext_lazy as _
 
 from merengue.pluggable import Plugin
@@ -17,7 +34,11 @@ class PluginConfig(Plugin):
     version = '0.0.1a'
 
     config_params = [
-        params.Single(name='limit', label=_('limit for templatetags'), default='3'),
+        params.PositiveInteger(
+            name='limit',
+            label=_('number of news for the "Latest news" block'),
+            default=3,
+        ),
     ]
 
     url_prefixes = (
